r"""
:mod:`qp` is...

    >>> import qp
"""

# Sphinx automodule relies on modules being exposed through `__all__` here

__all__ = []  # type: ignore

__author__ = "Louis Maddox"
__license__ = "MIT"
__description__ = "Pandas API reference"
__url__ = "https://github.com/qu-arx/qp"
__uri__ = __url__
__email__ = "louismmx@gmail.com"
